# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deepproto/proto/poll/v1/poll.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepproto.proto.resource.v1 import resource_pb2 as deepproto_dot_proto_dot_resource_dot_v1_dot_resource__pb2
from deepproto.proto.tracepoint.v1 import tracepoint_pb2 as deepproto_dot_proto_dot_tracepoint_dot_v1_dot_tracepoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"deepproto/proto/poll/v1/poll.proto\x12\x17\x64\x65\x65pproto.proto.poll.v1\x1a*deepproto/proto/resource/v1/resource.proto\x1a.deepproto/proto/tracepoint/v1/tracepoint.proto\"n\n\x0bPollRequest\x12\x10\n\x08ts_nanos\x18\x01 \x01(\x06\x12\x14\n\x0c\x63urrent_hash\x18\x02 \x01(\t\x12\x37\n\x08resource\x18\x03 \x01(\x0b\x32%.deepproto.proto.resource.v1.Resource\"\xb7\x01\n\x0cPollResponse\x12\x10\n\x08ts_nanos\x18\x01 \x01(\x06\x12\x14\n\x0c\x63urrent_hash\x18\x02 \x01(\t\x12\x41\n\x08response\x18\x03 \x03(\x0b\x32/.deepproto.proto.tracepoint.v1.TracePointConfig\x12<\n\rresponse_type\x18\x04 \x01(\x0e\x32%.deepproto.proto.poll.v1.ResponseType*)\n\x0cResponseType\x12\r\n\tNO_CHANGE\x10\x00\x12\n\n\x06UPDATE\x10\x01\x32\x63\n\nPollConfig\x12U\n\x04poll\x12$.deepproto.proto.poll.v1.PollRequest\x1a%.deepproto.proto.poll.v1.PollResponse\"\x00\x42P\n com.intergral.deep.proto.poll.v1P\x01Z*github.com/intergral/go-deep-proto/poll/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deepproto.proto.poll.v1.poll_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n com.intergral.deep.proto.poll.v1P\001Z*github.com/intergral/go-deep-proto/poll/v1'
  _RESPONSETYPE._serialized_start=453
  _RESPONSETYPE._serialized_end=494
  _POLLREQUEST._serialized_start=155
  _POLLREQUEST._serialized_end=265
  _POLLRESPONSE._serialized_start=268
  _POLLRESPONSE._serialized_end=451
  _POLLCONFIG._serialized_start=496
  _POLLCONFIG._serialized_end=595
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deepproto/proto/common/v1/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&deepproto/proto/common/v1/common.proto\x12\x19\x64\x65\x65pproto.proto.common.v1\"\x84\x02\n\x08\x41nyValue\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x02 \x01(\x08H\x00\x12\x13\n\tint_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12<\n\x0b\x61rray_value\x18\x05 \x01(\x0b\x32%.deepproto.proto.common.v1.ArrayValueH\x00\x12?\n\x0ckvlist_value\x18\x06 \x01(\x0b\x32\'.deepproto.proto.common.v1.KeyValueListH\x00\x12\x15\n\x0b\x62ytes_value\x18\x07 \x01(\x0cH\x00\x42\x07\n\x05value\"A\n\nArrayValue\x12\x33\n\x06values\x18\x01 \x03(\x0b\x32#.deepproto.proto.common.v1.AnyValue\"C\n\x0cKeyValueList\x12\x33\n\x06values\x18\x01 \x03(\x0b\x32#.deepproto.proto.common.v1.KeyValue\"K\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.deepproto.proto.common.v1.AnyValueBT\n\"com.intergral.deep.proto.common.v1P\x01Z,github.com/intergral/go-deep-proto/common/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deepproto.proto.common.v1.common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.intergral.deep.proto.common.v1P\001Z,github.com/intergral/go-deep-proto/common/v1'
  _ANYVALUE._serialized_start=70
  _ANYVALUE._serialized_end=330
  _ARRAYVALUE._serialized_start=332
  _ARRAYVALUE._serialized_end=397
  _KEYVALUELIST._serialized_start=399
  _KEYVALUELIST._serialized_end=466
  _KEYVALUE._serialized_start=468
  _KEYVALUE._serialized_end=543
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deepproto/proto/resource/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepproto.proto.common.v1 import common_pb2 as deepproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*deepproto/proto/resource/v1/resource.proto\x12\x1b\x64\x65\x65pproto.proto.resource.v1\x1a&deepproto/proto/common/v1/common.proto\"e\n\x08Resource\x12\x37\n\nattributes\x18\x01 \x03(\x0b\x32#.deepproto.proto.common.v1.KeyValue\x12 \n\x18\x64ropped_attributes_count\x18\x02 \x01(\rBX\n$com.intergral.deep.proto.resource.v1P\x01Z.github.com/intergral/go-deep-proto/resource/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deepproto.proto.resource.v1.resource_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$com.intergral.deep.proto.resource.v1P\001Z.github.com/intergral/go-deep-proto/resource/v1'
  _RESOURCE._serialized_start=115
  _RESOURCE._serialized_end=216
# @@protoc_insertion_point(module_scope)
